from setuptools import setup
  
# reading long description from file
# with open('DESCRIPTION.txt') as file:
#     long_description = file.read()
  
  
# specify requirements of your package here
#REQUIREMENTS = ['requests', 'pandas', 'snowflake.connector']
  
# some more details
# CLASSIFIERS = [
#     'Development Status :: 4 - Beta',
#     'Intended Audience :: Developers',
#     'Topic :: Internet',
#     'License :: OSI Approved :: MIT License',
#     'Programming Language :: Python',
#     'Programming Language :: Python :: 3.10',
#     ]
  
# calling the setup function 
# setup(name='ktbox',
#       version='0.0.1',
#       description='A small wrapper around sfpdil connection',
#       long_description=long_description,
#       url='https://gitlab.com/work435/ktbox',
#       author='Krzysztof',
#       author_email='my@mail.com',
#       license='MIT',
#       packages=['ktbox'],
#       classifiers=CLASSIFIERS,
#       install_requires=REQUIREMENTS,
#       keywords='pdil'
#       )

setup(
    version='0.0.2'
)